<?php

/**
 * cgs-vinyl functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package cgs-vinyl
 */

if (! defined('_S_VERSION')) {
	// Replace the version number of the theme on each release.
	define('_S_VERSION', '1.0.0');
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function cgs_vinyl_setup()
{
	/*
		* Make theme available for translation.
		* Translations can be filed in the /languages/ directory.
		* If you're building a theme based on cgs-vinyl, use a find and replace
		* to change 'cgs-vinyl' to the name of your theme in all the template files.
		*/
	load_theme_textdomain('cgs-vinyl', get_template_directory() . '/languages');

	// Add default posts and comments RSS feed links to head.
	add_theme_support('automatic-feed-links');

	/*
		* Let WordPress manage the document title.
		* By adding theme support, we declare that this theme does not use a
		* hard-coded <title> tag in the document head, and expect WordPress to
		* provide it for us.
		*/
	add_theme_support('title-tag');

	/*
		* Enable support for Post Thumbnails on posts and pages.
		*
		* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		*/
	add_theme_support('post-thumbnails');

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus(
		array(
			'primary-menu' 			 => esc_html__('Primary - Menu', 'all-care-home-repair'),
			'footer-navigation-menu' => esc_html__('Footer - Navigation Menu', 'all-care-home-repair'),
			'footer-services-menu'   => esc_html__('Footer - Services Menu', 'all-care-home-repair'),
			'seo-menu' 				 => esc_html__('Seo Menu', 'all-care-home-repair'),
			'footer-policies-menu'   => esc_html__('Footer - Policies Menu', 'all-care-home-repair')
		)
	);


	/*
		* Switch default core markup for search form, comment form, and comments
		* to output valid HTML5.
		*/
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'style',
			'script',
		)
	);

	// Set up the WordPress core custom background feature.
	add_theme_support(
		'custom-background',
		apply_filters(
			'cgs_vinyl_custom_background_args',
			array(
				'default-color' => 'ffffff',
				'default-image' => '',
			)
		)
	);

	// Add theme support for selective refresh for widgets.
	add_theme_support('customize-selective-refresh-widgets');

	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support(
		'custom-logo',
		array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		)
	);
}
add_action('after_setup_theme', 'cgs_vinyl_setup');

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function cgs_vinyl_content_width()
{
	$GLOBALS['content_width'] = apply_filters('cgs_vinyl_content_width', 640);
}
add_action('after_setup_theme', 'cgs_vinyl_content_width', 0);

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function cgs_vinyl_widgets_init()
{
	register_sidebar(
		array(
			'name'          => esc_html__('Sidebar', 'cgs-vinyl'),
			'id'            => 'sidebar-1',
			'description'   => esc_html__('Add widgets here.', 'cgs-vinyl'),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action('widgets_init', 'cgs_vinyl_widgets_init');

/**
 * Enqueue scripts and styles.
 */
function cgs_vinyl_scripts()
{

	wp_enqueue_style('cgs-vinyl-layout-min-css', get_template_directory_uri() . '/assets/css/layout.min.css', array(), '20151215');
	wp_enqueue_style('cgs-vinyl-jquery-fancybox-min-css', get_template_directory_uri() . '/assets/css/jquery.fancybox.min.css', array(), '20151215');

	wp_enqueue_style('cgs-vinyl-style', get_stylesheet_uri(), array(), _S_VERSION);
	wp_style_add_data('cgs-vinyl-style', 'rtl', 'replace');

	wp_enqueue_script('cgs-vinyl-custom-js', get_template_directory_uri() . '/assets/js/custom.js', array(), _S_VERSION, true);
	wp_enqueue_script('cgs-vinyl-layout-js', get_template_directory_uri() . '/assets/js/layout.js', array(), '20151215', true);
	wp_enqueue_script('cgs-vinyl-slick-min-js', get_template_directory_uri() . '/assets/js/slick.min.js', array(), '20151215', true);
	wp_enqueue_script('cgs-vinyl-simplebar-js', get_template_directory_uri() . '/assets/js/simplebar.js', array(), '20151215', true);
	wp_enqueue_script('cgs-vinyl-jquery-fancybox-min-js', get_template_directory_uri() . '/assets/js/jquery.fancybox.min.js', array(), '20151215', true);
	wp_localize_script('cgs-vinyl-custom-js', 'custom_call', ['ajaxurl' => admin_url('admin-ajax.php'), 'homeurl' => home_url()]);
	wp_enqueue_script('cgs-vinyl-navigation', get_template_directory_uri() . '/js/navigation.js', array(), _S_VERSION, true);

	if (is_singular() && comments_open() && get_option('thread_comments')) {
		wp_enqueue_script('comment-reply');
	}
}
add_action('wp_enqueue_scripts', 'cgs_vinyl_scripts');

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if (defined('JETPACK__VERSION')) {
	require get_template_directory() . '/inc/jetpack.php';
}

// Filter the output of the logo to fix Google errors about itemprop logo
add_filter('get_custom_logo', 'change_html_custom_logo');
function change_html_custom_logo()
{
	$custom_logo_id = get_theme_mod('custom_logo');
	$site_name = get_bloginfo('name');
	$html = sprintf(
		'<a href="%1$s" class="custom-logo-link" rel="home" title="' . $site_name . '">%2$s</a>',
		esc_url(home_url('/')),
		wp_get_attachment_image($custom_logo_id, 'full', false, array(
			'class'    => 'custom-logo',
			'alt' => $site_name . ' logo'
		))
	);
	return $html;
}

function search_filter($query)
{
	if (!is_admin() && $query->is_main_query()) {
		if ($query->is_search) {
			$query->set('post_type', 'post');
		}
	}
}
add_action('pre_get_posts', 'search_filter');


function common_banner($title){
$common_banner_background_image = get_field('common_banner_background_image','option');
?>
	<section class="main-banner inner-banner" <?php echo esc_url($common_banner_background_image) ? "style='background-image: url(" . esc_url($common_banner_background_image) . ");'" : "" ?>>
		<div class="container">
			<div class="row">
				<div class="col-12">
					<div class="banner-content white-text">
						<h1 class="h1-title"><?php echo $title; ?></h1>
					</div>
				</div>
			</div>
		</div>
	</section>
	<!-- Banner End -->
<?php
}


// Conditionally include the custom-function.php file
if (file_exists(get_template_directory() . '/custom-function.php')) {
	require get_template_directory() . '/custom-function.php';
}


//function to load image and video
function load_image_video() {
    $tab_id = $_POST['tab'];
    $page_id = $_POST['page_id'];
    $current_page = isset($_POST['currentpage']) ? intval($_POST['currentpage']) : 1;
    
    $items_per_page = 6; 
    $offset = ($current_page - 1) * $items_per_page;
    
    $output = '';
    
    if (have_rows('project_image_and_video', $page_id)) {
        while (have_rows('project_image_and_video', $page_id)) {
            the_row();
        
            if ($tab_id === 'Images') { 
                $projects_images = get_sub_field('projects_images');
                if (is_array($projects_images) && !empty($projects_images)) {
                    $total_images = count($projects_images);
                    $total_pages = ceil($total_images / $items_per_page);
                    
                    $images_to_show = array_slice($projects_images, $offset, $items_per_page);
                    
                    foreach($images_to_show as $image) {
                        $output .= "<div class='col-lg-4' data-total-page='$total_pages'>";
                        $output .= "<a href='".esc_url($image)."' title='Image' data-fancybox='image'>";
                        $output .= "<div class='back-img' style='background-image: url(".esc_url($image).");'></div>";
                        $output .= "</a></div>";
                    }
                }
            } else { 
                $rows = get_sub_field('projects_videos');
                if (is_array($rows) && !empty($rows)) {
                    $total_video = count($rows);
                    $total_pages = ceil($total_video / $items_per_page);
                    
                    $count = 0;
                    while ($count < $total_video) {
                        if ($count >= $offset && $count < ($offset + $items_per_page)) {
                            $video_thumbnail = $rows[$count]['video_thumbnail'];
                            $video_url = $rows[$count]['video_url'];
                            $output .= "<div class='col-lg-4' data-total-page='$total_pages'>";
                            $output .= "<a href='".esc_url($video_url)."' title='Video' data-fancybox='video'>";
                            $output .= "<div class='back-img' style='background-image: url(".esc_url($video_thumbnail).");'>";
                            $output .= "<div class='play-btn'></div></div></a></div>";
                        }
                        $count++;
                    }
                }
            }
        }
    }
    
    echo $output;
    wp_die();
}

add_action("wp_ajax_load_image_video", "load_image_video");
add_action("wp_ajax_nopriv_load_image_video", "load_image_video");
