<?php
// Add a meta box to the post edit screen
function add_featured_post_meta_box() {
    add_meta_box(
        'featured_post_meta_box', // ID
        'Featured Post',          // Title
        'render_featured_post_meta_box', // Callback
        'testimonial',                   // Post type
        'side',                   // Context
        'default'                 // Priority
    );
}
add_action('add_meta_boxes', 'add_featured_post_meta_box');

// Render the meta box content
function render_featured_post_meta_box($post) {
    // Add a nonce field so we can check for it later.
    wp_nonce_field('save_featured_post_meta_box', 'featured_post_meta_box_nonce');

    // Use get_post_meta to retrieve an existing value from the database.
    $value = get_post_meta($post->ID, 'featured_post', true);

    // Display the meta box form
    echo '<label for="featured_post">';
    echo '<input type="checkbox" id="featured_post" name="featured_post" value="1" ' . checked($value, 1, false) . ' />';
    echo ' Mark as Featured Post';
    echo '</label>';
}

// Save the meta box data
function save_featured_post_meta_box($post_id) {
    // Check if our nonce is set.
    if (!isset($_POST['featured_post_meta_box_nonce'])) {
        return $post_id;
    }

    $nonce = $_POST['featured_post_meta_box_nonce'];

    // Verify that the nonce is valid.
    if (!wp_verify_nonce($nonce, 'save_featured_post_meta_box')) {
        return $post_id;
    }

    // If this is an autosave, our form has not been submitted, so we don't want to do anything.
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return $post_id;
    }

    // Check the user's permissions.
    if ('post' == $_POST['post_type']) {
        if (!current_user_can('edit_post', $post_id)) {
            return $post_id;
        }
    }

    // Update the meta field in the database.
    if (isset($_POST['featured_post'])) {

        $featured = 1;
        update_post_meta($post_id, 'featured_post', $featured);

        $args = array(
            'post_type' => 'testimonial',
            'post_status' => 'publish',
            'post__not_in' => array($post_id), 
            'meta_query' => array(
                array(
                    'key' => 'featured_post',
                    'value' => '1',
                ),
            ),
        );
        $query = new WP_Query($args);

        if ($query->have_posts()) {
            while ($query->have_posts()) {
                $query->the_post();
                $other_post_id = get_the_ID();
                update_post_meta($other_post_id, 'featured_post', 0);
            }
            wp_reset_postdata();
        }
    }
    // $featured = isset($_POST['featured_post']) ? 1 : 0;
    // update_post_meta($post_id, 'featured_post', $featured);
}
add_action('save_post', 'save_featured_post_meta_box');

// Modify the columns in the post listing
function add_featured_post_column($columns) {
    $columns['featured_post'] = __('Featured');
    return $columns;
}
add_filter('manage_testimonial_posts_columns', 'add_featured_post_column');

// Render the featured post column in the post listing
function render_featured_post_column($column, $post_id) {
    if ('featured_post' === $column) {
        $is_featured = get_post_meta($post_id, 'featured_post', true);
        echo $is_featured ? '★' : '☆';
    }
}
add_action('manage_testimonial_posts_custom_column', 'render_featured_post_column', 10, 2);

//Split number and character function
function split_string($input) {
    // Use regular expression to match numbers and characters
    if (preg_match('/^(\d+)([\+\-\*\%\/]?)$/', $input, $matches)) {
        return [
            'number' => $matches[1],
            'character' => $matches[2]
        ];
    } else {
        // Return null values if the input does not match the expected format
        return [
            'number' => null,
            'character' => null
        ];
    }
}


